#!/usr/bin/env python
#Author: Mark Feineigle
#Create Date: 2017/06/24
import argparse
from datetime import datetime as dt
import json
import matplotlib.pyplot as plt
import os
import sys

parser = argparse.ArgumentParser()
parser.add_argument("site", help="""site to parse = conected,
                                                    desertgo,
                                                    feineigle""")
parser.add_argument("-y", "--year", default=str(dt.now().year),
                                    help="""Year to parse.
                                            Default is this year.""")
parser.add_argument("-m", "--month", default=str(dt.now().month-1),
                                     help="""Month to parse (1-12).
                                             Default is LAST month.""")
parser.add_argument("-a", "--all", action="store_true",
                                   help="Parse all months.")
parser.add_argument("--nobaidu", action="store_true",
                                 help="Don't plot baidu spider hits.")
args = parser.parse_args()

def read_json_log(logPath):
  with open(logPath, "r") as fi:
    data = fi.read()
    data = data[data.find("{"):] #cut off the first 2 lines/header (hits)
    data = json.loads(data)
  return data

def parse_json(data):
  xs, ys = [], []
  for key, val in sorted(data.items()):
    xs.append(float(key[-2:])) #key/xs = days
    if args.nobaidu == True:
      val = [v for v in val if not v.startswith("180.76.15.")]
    ys.append(float(len(val))) #val/ys = hits
  return (xs, ys)

def construct_plot(xs, ys, site, filename):
  if args.nobaidu == True:
    filename = filename+"_nobaidu"
  plt.figure(figsize=(10.24,6))
  plt.bar(xs, ys, align="center")
  plt.xticks(xs)
  plt.title(filename)
  plt.xlabel("Days")
  plt.ylabel("Hits")
  plt.grid(True)
  plt.tight_layout(1)
  plt.rcParams["savefig.facecolor"] = "darkgrey"
  #plt.show() #NOTE remove after tests
  if not os.path.exists(os.path.join(site, "img")):
    os.mkdir(os.path.join(site, "img"))
  plt.savefig(os.path.join(site, "img", filename+".png"))
  plt.clf() #clear in case of loop

def process_log(logPath, site, filename):
  try:
    data = read_json_log(logPath)
  except IOError as e:
    return
  xs, ys = parse_json(data)
  if len(xs) == 0: #there is no data
    return
  print "Processing {}\r".format(filename),
  sys.stdout.flush()
  construct_plot(xs, ys, site, filename)

if __name__ == "__main__":
  site = args.site
  year = args.year
  months = [args.month.zfill(2)]
  if args.all == True:
    months = [str(m).zfill(2) for m in range(1,13)]
  for month in months:
    filename = site+"_"+year+"-"+month
    logPath = site+"/"+filename+".txt"
    process_log(logPath, site, filename)
  print ""
